@@ -45,6 +45,7 @@ struct _pu_config_setting {
 
   {"CleanMethod",     PU_CONFIG_OPTION_CLEANMETHOD},
   {"Color",           PU_CONFIG_OPTION_COLOR},
+  {"NoProgressBar",   PU_CONFIG_OPTION_NOPROGRESSBAR},
   {"UseSyslog",       PU_CONFIG_OPTION_USESYSLOG},
   {"CheckSpace",      PU_CONFIG_OPTION_CHECKSPACE},
   {"VerbosePkgLists", PU_CONFIG_OPTION_VERBOSEPKGLISTS},
@@ -71,6 +72,8 @@ struct _pu_config_setting {
 
   {"Server",          PU_CONFIG_OPTION_SERVER},
 
+  {"CacheServer",     PU_CONFIG_OPTION_CACHESERVER},
+
   {NULL, 0}
 };
 
@@ -258,6 +261,7 @@ pu_config_t *pu_config_new(void) {
 
   config->checkspace = PU_CONFIG_BOOL_UNSET;
   config->color = PU_CONFIG_BOOL_UNSET;
+  config->noprogressbar = PU_CONFIG_BOOL_UNSET;
   config->disabledownloadtimeout = PU_CONFIG_BOOL_UNSET;
   config->ilovecandy = PU_CONFIG_BOOL_UNSET;
   config->usesyslog = PU_CONFIG_BOOL_UNSET;
@@ -277,6 +281,7 @@ void pu_repo_free(pu_repo_t *repo) {
 
   free(repo->name);
   FREELIST(repo->servers);
+  FREELIST(repo->cacheservers);
 
   free(repo);
 }
@@ -332,6 +337,27 @@ static int _pu_subst_server_vars(pu_config_t *config) {
         }
       }
 
+      rrepo = _pu_strreplace(s->data, "$repo", repo->name);
+      if (rrepo == NULL) { return -1; }
+      free(s->data);
+      s->data = rrepo;
+    }
+    for (s = repo->cacheservers; s; s = s->next) {
+      char *rrepo;
+
+      if (strstr(s->data, "$arch")) {
+        if (config->architectures == NULL) {
+          errno = EINVAL;
+          return -1;
+        } else {
+          char *arch = config->architectures->data;
+          char *rarch = _pu_strreplace(s->data, "$arch", arch);
+          if (rarch == NULL) { return -1; }
+          free(s->data);
+          s->data = rarch;
+        }
+      }
+
       rrepo = _pu_strreplace(s->data, "$repo", repo->name);
       if (rrepo == NULL) { return -1; }
       free(s->data);
@@ -383,6 +409,7 @@ alpm_db_t *pu_register_syncdb(alpm_handle_t *handle, pu_repo_t *repo) {
   alpm_db_t *db = alpm_register_syncdb(handle, repo->name, repo->siglevel);
   if (db) {
     alpm_db_set_servers(db, alpm_list_strdup(repo->servers));
+    alpm_db_set_cache_servers(db, alpm_list_strdup(repo->cacheservers));
     alpm_db_set_usage(db, repo->usage);
   }
   return db;
@@ -435,6 +462,20 @@ int pu_config_resolve_sysroot(pu_config_t *config, const char *sysroot) {
         s->data = newsrv;
       }
     }
+    for (s = r->cacheservers; s; s = s->next) {
+      if (strncmp("file://", s->data, 7) == 0) {
+        char *newdir = NULL, *newsrv = NULL;
+        if ((newdir = pu_prepend_dir(sysroot, (char *)s->data + 7)) == NULL
+            || (newsrv = pu_asprintf("file://%s", newdir)) == NULL) {
+          free(newdir);
+          free(newsrv);
+          return 1;
+        }
+        free(newdir);
+        free(s->data);
+        s->data = newsrv;
+      }
+    }
   }
 
 #undef PU_SETSYSROOT
@@ -473,6 +514,7 @@ int pu_config_resolve(pu_config_t *config) {
 #define SETBOOL(opt) if(opt == -1) { opt = 0; }
   SETBOOL(config->checkspace);
   SETBOOL(config->color);
+  SETBOOL(config->noprogressbar);
   SETBOOL(config->disabledownloadtimeout);
   SETBOOL(config->ilovecandy);
   SETBOOL(config->usesyslog);
@@ -515,6 +557,7 @@ void pu_config_merge(pu_config_t *dest, pu_config_t *src) {
   MERGEBOOL(dest->checkspace, src->checkspace);
   MERGEBOOL(dest->verbosepkglists, src->verbosepkglists);
   MERGEBOOL(dest->color, src->color);
+  MERGEBOOL(dest->noprogressbar, src->noprogressbar);
   MERGEBOOL(dest->ilovecandy, src->ilovecandy);
   MERGEBOOL(dest->disabledownloadtimeout, src->disabledownloadtimeout);
 
@@ -720,6 +763,11 @@ int pu_config_reader_next(pu_config_reader_t *reader) {
             _PU_ERR(reader, PU_CONFIG_READER_STATUS_ERROR);
           }
           break;
+        case PU_CONFIG_OPTION_CACHESERVER:
+          if (pu_list_append_str(&r->cacheservers, mini->value) == NULL) {
+            _PU_ERR(reader, PU_CONFIG_READER_STATUS_ERROR);
+          }
+          break;
         case PU_CONFIG_OPTION_USAGE:
           if (_pu_config_parse_usage(mini->value, &r->usage) != 0) {
             _PU_ERR(reader, PU_CONFIG_READER_STATUS_INVALID_VALUE);
@@ -817,6 +865,9 @@ int pu_config_reader_next(pu_config_reader_t *reader) {
         case PU_CONFIG_OPTION_COLOR:
           config->color = 1;
           break;
+        case PU_CONFIG_OPTION_NOPROGRESSBAR:
+          config->noprogressbar = 1;
+          break;
         case PU_CONFIG_OPTION_USESYSLOG:
           config->usesyslog = 1;
           break;
@@ -906,4 +957,3 @@ void pu_config_reader_free(pu_config_reader_t *reader) {
   pu_config_reader_free(reader->_parent);
   free(reader);
 }
-/* vim: set ts=2 sw=2 et: */
